#!/bin/sh
#
# get_drbd_stat.sh - Gather stats from /proc/drbd.
#
# The purpose of this script is to be used from an snmpd.conf file.
# Used by Cricket to draw nice statistics
#
# History
# -------
# 2004/04/29	mex@belga.be	Created
#


STATS_TMP=/tmp/drbd_stats.$$
export STATS_TMP

# Do we run drbd?
MOD=`/sbin/lsmod drbd | grep drbd`
if [ "x$MOD" = "x" ]; then
	# Module not loaded?
	# Silent exit with a return code
	exit -1
fi

# Access only one time the /proc fs (for performance)
cat /proc/drbd | tail -1 >$STATS_TMP

# Extract stats.
# Based on DRBD 0.6.12
# Sample:
# 0: cs:Connected st:Primary/Secondary ns:10926252 nr:0 dw:323876 dr:10635313 pe:0 ua:0

# ns
cat $STATS_TMP | cut -d " " -f 4 | cut -d ":" -f 2
# nr
cat $STATS_TMP | cut -d " " -f 5 | cut -d ":" -f 2
# dw
cat $STATS_TMP | cut -d " " -f 6 | cut -d ":" -f 2
# dr
cat $STATS_TMP | cut -d " " -f 7 | cut -d ":" -f 2
# pe
cat $STATS_TMP | cut -d " " -f 8 | cut -d ":" -f 2
# ua
cat $STATS_TMP | cut -d " " -f 9 | cut -d ":" -f 2

/bin/rm $STATS_TMP
exit 0
